@@ -60,7 +60,7 @@ const char* WHERE_MARK = "where-marker";
 
 class SourceView : public gtksourceview::SourceView {
 
-    sigc::signal<void, int> m_marker_region_got_clicked_signal ;
+    sigc::signal<void, int, bool> m_marker_region_got_clicked_signal ;
 
 public:
     SourceView (Glib::RefPtr<SourceBuffer> &a_buf) :
@@ -85,8 +85,7 @@ public:
     void enable_events ()
     {
         add_events (Gdk::LEAVE_NOTIFY_MASK
-                    |Gdk::BUTTON_PRESS_MASK
-                    |Gdk::KEY_PRESS_MASK) ;
+                    |Gdk::BUTTON_PRESS_MASK) ;
     }
 
     void do_custom_button_press_event_handling (GdkEventButton *a_event)
@@ -116,7 +115,8 @@ public:
         THROW_IF_FAIL (iter) ;
 
         LOG_DD ("got clicked on line: " << iter.get_line ()) ;
-        marker_region_got_clicked_signal ().emit (iter.get_line ()) ; ;
+        marker_region_got_clicked_signal ().emit (iter.get_line (),
+                                                  false/*no dialog requested*/);
     }
 
     bool on_button_press_event (GdkEventButton *a_event)
@@ -130,13 +130,7 @@ public:
         }
     }
 
-    bool on_key_press_event (GdkEventKey *a_event)
-    {
-        Gtk::Widget::on_key_press_event (a_event) ;
-        return false ;
-    }
-
-    sigc::signal<void, int>& marker_region_got_clicked_signal ()
+    sigc::signal<void, int, bool>& marker_region_got_clicked_signal ()
     {
         return m_marker_region_got_clicked_signal ;
     }
@@ -158,7 +152,7 @@ struct SourceEditor::Priv {
     Gtk::Label *line_col_label ;
     Gtk::Label *line_count;
     sigc::signal<void, gint, gint> signal_insertion_moved ;
-    sigc::signal<void, int> marker_region_got_clicked_signal ;
+    sigc::signal<void, int, bool> marker_region_got_clicked_signal ;
     sigc::signal<void, const Gtk::TextBuffer::iterator&>
                                                     insertion_changed_signal;
     UString path ;
@@ -166,9 +160,9 @@ struct SourceEditor::Priv {
     //**************
     //<signal slots>
     //**************
-    void on_marker_region_got_clicked (int a_line)
+    void on_marker_region_got_clicked (int a_line, bool a_dialog_requested)
     {
-        marker_region_got_clicked_signal.emit (a_line) ;
+        marker_region_got_clicked_signal.emit (a_line, a_dialog_requested) ;
     }
 
     void on_mark_set_signal (const Gtk::TextBuffer::iterator &a_iter,
@@ -478,6 +472,8 @@ SourceEditor::set_visual_breakpoint_at_line (int a_line, bool enabled)
 {
     LOG_FUNCTION_SCOPE_NORMAL_DD
 
+    LOG_DD ("a_line: " << (int)a_line << "enabled: " << (int) enabled);
+
     UString marker_type;
     if (enabled) {
         marker_type = BREAKPOINT_ENABLED_CATEGORY;
@@ -779,7 +775,7 @@ SourceEditor::do_search (const UString &a_str,
     return false ;
 }
 
-sigc::signal<void, int>&
+sigc::signal<void, int, bool>&
 SourceEditor::marker_region_got_clicked_signal () const
 {
     return m_priv->marker_region_got_clicked_signal ;
